@@ -9,7 +9,9 @@ from pythainlp.corpus import (
     download,
     get_corpus_db,
     get_corpus_db_detail,
+    get_corpus_default_db,
     get_corpus_path,
+    oscar,
     provinces,
     remove,
     thai_family_names,
@@ -25,6 +27,7 @@ from pythainlp.corpus import (
 )
 from pythainlp.corpus.util import revise_newmm_default_wordset
 from requests import Response
+import nltk
 
 
 class TestCorpusPackage(unittest.TestCase):
@@ -72,6 +75,10 @@ class TestCorpusPackage(unittest.TestCase):
         )  # corpus name not exist
         self.assertIsNotNone(get_corpus_db_detail("test"))  # corpus exists
         self.assertIsNotNone(get_corpus_path("test"))  # corpus exists
+        self.assertIsNone(get_corpus_default_db("test"))
+        self.assertIsNotNone(get_corpus_default_db("thainer", "1.5.1"))
+        self.assertIsNotNone(get_corpus_default_db("thainer"))
+        self.assertIsNone(get_corpus_default_db("thainer", "1.2"))
         self.assertTrue(remove("test"))  # remove existing
         self.assertFalse(remove("test"))  # remove non-existing
         self.assertIsNone(get_corpus_path("XXXkdjfBzc"))  # query non-existing
@@ -99,14 +106,23 @@ class TestCorpusPackage(unittest.TestCase):
         self.assertIsNotNone(download(name="test", version="0.1"))
         self.assertIsNotNone(remove("test"))
 
+    def test_oscar(self):
+        self.assertIsNotNone(oscar.word_freqs())
+        self.assertIsNotNone(oscar.unigram_word_freqs())
+
     def test_tnc(self):
         self.assertIsNotNone(tnc.word_freqs())
+        self.assertIsNotNone(tnc.unigram_word_freqs())
+        self.assertIsNotNone(tnc.bigram_word_freqs())
+        self.assertIsNotNone(tnc.trigram_word_freqs())
 
     def test_ttc(self):
         self.assertIsNotNone(ttc.word_freqs())
+        self.assertIsNotNone(ttc.unigram_word_freqs())
 
     def test_wordnet(self):
-        self.assertIsInstance(wordnet.langs(), list)
+        nltk.download('omw-1.4', force=True)  # load wordnet
+        self.assertIsNotNone(wordnet.langs())
         self.assertIn("tha", wordnet.langs())
 
         self.assertEqual(
