@@ -610,9 +610,14 @@ class TestTokenizePackage(unittest.TestCase):
         self.assertEqual(nercut.segment(None), [])
         self.assertEqual(nercut.segment(""), [])
         self.assertIsNotNone(nercut.segment("ทดสอบ"))
-        self.assertIsNotNone(nercut.segment("ทุ๊กกโคนน"))
-        self.assertIsNotNone(nercut.segment("อือหือ"))
-        self.assertIsNotNone(nercut.segment("อย่าลืมอัพการ์ดนะจ๊ะ"))
+        self.assertEqual(nercut.segment("ทันแน่ๆ"), ['ทัน', 'แน่ๆ'])
+        self.assertEqual(nercut.segment("%1ครั้ง"), ['%', '1', 'ครั้ง'])
+        self.assertEqual(nercut.segment("ทุ๊กกโคนน"), ['ทุ๊กกโคนน'])
+        self.assertEqual(nercut.segment("อือหือ"), ['อือหือ'])
+        self.assertEqual(
+            nercut.segment("อย่าลืมอัพการ์ดนะจ๊ะ"),
+            ['อย่าลืมอัพการ์ดนะจ๊ะ']
+        )
         self.assertIsNotNone(word_tokenize("ทดสอบ", engine="nercut"))
 
     def test_ssg(self):
