@@ -3,9 +3,10 @@
 import unittest
 
 import torch
-from pythainlp.transliterate import romanize, transliterate, pronunciate
+from pythainlp.transliterate import romanize, transliterate, pronunciate, puan
 from pythainlp.transliterate.ipa import trans_list, xsampa_list
 from pythainlp.transliterate.thai2rom import ThaiTransliterator
+from pythainlp.corpus import remove
 
 _BASIC_TESTS = {
     None: "",
@@ -56,6 +57,7 @@ class TestTransliteratePackage(unittest.TestCase):
         self.assertEqual(romanize(None), "")
         self.assertEqual(romanize(""), "")
         self.assertEqual(romanize("แมว"), "maeo")
+        self.assertEqual(romanize("แมว", engine="tltk"), "maeo")
 
     def test_romanize_royin_basic(self):
         for word in _BASIC_TESTS:
@@ -135,13 +137,28 @@ class TestTransliteratePackage(unittest.TestCase):
         self.assertEqual(transliterate("คน", engine="ipa"), "kʰon")
         self.assertIsNotNone(transliterate("คน", engine="thaig2p"))
         self.assertIsNotNone(transliterate("แมว", engine="thaig2p"))
+        self.assertIsNotNone(transliterate("คน", engine="tltk_g2p"))
+        self.assertIsNotNone(transliterate("แมว", engine="tltk_g2p"))
+        self.assertIsNotNone(transliterate("คน", engine="tltk_ipa"))
+        self.assertIsNotNone(transliterate("แมว", engine="tltk_ipa"))
         self.assertIsNotNone(trans_list("คน"))
         self.assertIsNotNone(xsampa_list("คน"))
 
     def test_pronunciate(self):
         self.assertEqual(pronunciate(""), "")
+        remove("thai_w2p")
         self.assertIsNotNone(pronunciate("คน", engine="w2p"))
         self.assertIsNotNone(pronunciate("แมว", engine="w2p"))
         self.assertIsNotNone(pronunciate("มข.", engine="w2p"))
         self.assertIsNotNone(pronunciate("มช.", engine="w2p"))
         self.assertIsNotNone(pronunciate("jks", engine="w2p"))
+
+    def test_puan(self):
+        self.assertEqual(puan("แมว"), "แมว")
+        self.assertEqual(puan("นาริน"), "นิน-รา")
+        self.assertEqual(puan("นาริน", show_pronunciation=False), "นินรา")
+        self.assertEqual(puan("แสงดีนะ"), "แสง-ดะ-นี")
+        self.assertEqual(puan("แสงดีนะ", show_pronunciation=False), "แสงดะนี")
+        self.assertEqual(
+            puan("การทำความดี", show_pronunciation=False), "ดานทำความกี"
+        )
