@@ -29,7 +29,16 @@ from pythainlp.ulmfit.preprocess import (
     spec_add_spaces,
     ungroup_emoji,
 )
-from pythainlp.ulmfit.tokenizer import BaseTokenizer
+from pythainlp.ulmfit.tokenizer import BaseTokenizer as base_tokenizer
+import pandas as pd
+import pickle
+import torch
+# fastai
+import fastai
+from fastai.text import *
+
+# pythainlp
+from pythainlp.ulmfit import *
 
 
 class TestUlmfitPackage(unittest.TestCase):
@@ -39,7 +48,7 @@ class TestUlmfitPackage(unittest.TestCase):
         self.assertIsNone(self.thai.add_special_cases(["แมว"]))
 
     def test_BaseTokenizer(self):
-        self.base = BaseTokenizer(lang="th")
+        self.base = base_tokenizer(lang="th")
         self.assertIsNotNone(self.base.tokenizer("ทดสอบ การ ตัด คำ"))
         self.assertIsNone(self.base.add_special_cases(["แมว"]))
 
@@ -104,6 +113,9 @@ class TestUlmfitPackage(unittest.TestCase):
     def test_remove_space(self):
         self.assertEqual(remove_space([" ", "น้อย", " ", "."]), ["น้อย", "."])
 
+    def test_replace_url(self):
+        self.assertEqual(replace_url("https://thainlp.org web"), "xxurl web")
+
     def test_rm_useless_newlines(self):
         self.assertEqual(rm_useless_newlines("text\n\n"), "text ")
 
@@ -198,3 +210,74 @@ class TestUlmfitPackage(unittest.TestCase):
         ]
 
         self.assertEqual(actual, expect)
+
+    def test_document_vector(self):
+        imdb = untar_data(URLs.IMDB_SAMPLE)
+        dummy_df = pd.read_csv(imdb/'texts.csv')
+        thwiki = THWIKI_LSTM
+        thwiki_itos = pickle.load(open(thwiki['itos_fname'], 'rb'))
+        thwiki_vocab = fastai.text.transform.Vocab(thwiki_itos)
+        tt = Tokenizer(
+            tok_func=ThaiTokenizer,
+            lang='th',
+            pre_rules=pre_rules_th,
+            post_rules=post_rules_th
+        )
+        processor = [
+            TokenizeProcessor(
+                tokenizer=tt, chunksize=10000, mark_fields=False
+            ),
+            NumericalizeProcessor(
+                vocab=thwiki_vocab, max_vocab=60000, min_freq=3
+            )
+        ]
+        data_lm = (
+            TextList.from_df(
+                dummy_df,
+                imdb,
+                cols=['text'],
+                processor=processor
+            )
+            .split_by_rand_pct(0.2)
+            .label_for_lm()
+            .databunch(bs=64)
+        )
+        data_lm.sanity_check()
+        config = dict(
+            emb_sz=400,
+            n_hid=1550,
+            n_layers=4,
+            pad_token=1,
+            qrnn=False,
+            tie_weights=True,
+            out_bias=True,
+            output_p=0.25,
+            hidden_p=0.1,
+            input_p=0.2,
+            embed_p=0.02,
+            weight_p=0.15
+        )
+        trn_args = dict(drop_mult=0.9, clip=0.12, alpha=2, beta=1)
+        learn = language_model_learner(
+            data_lm,
+            AWD_LSTM,
+            config=config,
+            pretrained=False,
+            **trn_args
+        )
+        learn.load_pretrained(**thwiki)
+        self.assertIsNotNone(
+            document_vector('วันนี้วันดีปีใหม่', learn, data_lm)
+        )
+        self.assertIsNotNone(
+            document_vector('วันนี้วันดีปีใหม่', learn, data_lm, agg="sum")
+        )
+        with self.assertRaises(ValueError):
+            document_vector('วันนี้วันดีปีใหม่', learn, data_lm, agg='abc')
+
+    def test_merge_wgts(self):
+        wgts = {'0.encoder.weight': torch.randn(5,3)}
+        itos_pre = ["แมว", "คน", "หนู"]
+        itos_new = ["ปลา", "เต่า", "นก"]
+        em_sz = 3
+        self.assertIsNotNone(merge_wgts(em_sz, wgts, itos_pre, itos_new))
